>From fdc9fe6bdec506710238b0c1e14c8858466b890f Mon Sep 17 00:00:00 2001
From: josch <j.schauer@email.de>
Date: Mon, 12 May 2014 17:45:21 +0200
Subject: [PATCH 2/3] add parse_expression to benl_utils

---
 lib/benl_utils.ml  | 11 +++++++++++
 lib/benl_utils.mli |  2 ++
 2 files changed, 13 insertions(+)

diff --git a/lib/benl_utils.ml b/lib/benl_utils.ml
index cb546f9..c899701 100644
--- a/lib/benl_utils.ml
+++ b/lib/benl_utils.ml
@@ -40,6 +40,17 @@ let parse_control_file kind filename keep f accu =
     parse_control_in_channel kind base ic keep f accu
   end
 
+let parse_expression expression =
+  let lexbuf = from_string expression in
+  try
+    Benl_parser.full_expr Benl_lexer.token lexbuf
+  with Benl_parser.Error ->
+    let pos = Lexing.lexeme_start_p lexbuf in
+    raise (Parsing_error
+             (pos.pos_fname,
+              pos.pos_lnum,
+              pos.pos_cnum-pos.pos_bol))
+
 let parse_config_file filename =
   with_in_file filename begin fun ic ->
     let lexbuf = from_channel ic in
diff --git a/lib/benl_utils.mli b/lib/benl_utils.mli
index ecde4e0..3aec701 100644
--- a/lib/benl_utils.mli
+++ b/lib/benl_utils.mli
@@ -29,6 +29,8 @@ val parse_control_file :
   ('a Package.Name.t -> 'a Package.t -> 'b -> 'b) ->
   'b -> 'b
 
+val parse_expression : string -> Benl_types.expr
+
 val parse_config_file : string -> Benl_types.config
 
 val file_content : string -> string
-- 
1.9.2

